/* BdfServer_API - Copyright (c) 2014-2021 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.api;

import fr.exemole.bdfserver.api.configuration.LangConfiguration;
import fr.exemole.bdfserver.api.groups.GroupDef;
import fr.exemole.bdfserver.api.policies.UserAllow;
import fr.exemole.bdfserver.api.roles.Role;
import fr.exemole.bdfserver.api.roles.RoleEditor;
import fr.exemole.bdfserver.api.subsettree.SubsetTree;
import fr.exemole.bdfserver.api.ui.UiComponent;
import fr.exemole.bdfserver.api.ui.UiComponents;
import fr.exemole.bdfserver.api.users.BdfUserPrefs;
import java.util.List;
import java.util.Locale;
import net.fichotheque.SubsetKey;
import net.fichotheque.selection.FicheQuery;
import net.fichotheque.sphere.Redacteur;
import net.mapeadores.util.attr.Attribute;
import net.mapeadores.util.attr.AttributeKey;
import net.mapeadores.util.localisation.Lang;
import net.mapeadores.util.localisation.LangPreference;
import net.mapeadores.util.text.Label;


/**
 *
 * @author Vincent Calame
 */
public interface BdfServerEditor {

    public BdfServer getBdfServer();

    public RoleEditor getRoleEditor();

    public boolean removeAttribute(Object attributesHolder, AttributeKey attributeKey);

    public boolean putAttribute(Object attributesHolder, Attribute attribute);

    public boolean putLabel(Object labelHolder, Label label);

    public boolean removeLabel(Object labelHolder, Lang lang);

    public void setWorkingLang(BdfUserPrefs bdfUserPrefs, Lang workingLang);

    public void setCustomFormatLocale(BdfUserPrefs bdfUserPrefs, Locale customFormatLocale);

    public void setCustomLangPreference(BdfUserPrefs bdfUserPrefs, LangPreference customLangPreference);

    public void setDefaultFicheQuery(BdfUserPrefs bdfUserPrefs, FicheQuery defaultFicheQuery, String defaultSortType);

    public void removeGroupDef(GroupDef groupDef);

    public GroupDef createGroupDef(String name);

    public void setSubsetTree(short subsetCategory, SubsetTree subsetTree);

    public void setLangConfiguration(LangConfiguration langConfiguration);

    public void setActiveExtensionList(List<String> activeExtensionList);

    public void setSubsetPolicy(SubsetKey subsetKey, Object policyObject);

    public boolean setUserAllow(UserAllow userAllow);

    public boolean setAdmin(String redacteurGlobalId, boolean isAdmin);

    public boolean link(Redacteur redacteur, Role role);

    public boolean unlink(String redacteurGlobalId, Role role);

    public boolean removeComponentUi(UiComponents uiComponents, String name);

    public boolean putComponentUi(UiComponents uiComponents, UiComponent componentUi);

    public boolean setPositionArray(UiComponents uiComponents, String[] nameArray);

    public void saveChanges();

}
