/* BdfServer - Copyright (c) 2015-2023 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.tools.ui.options;

import fr.exemole.bdfserver.api.ui.options.ValueOption;


/**
 *
 * @author Vincent Calame
 */
public class ValueOptionBuilder {

    private String defaultValue = "";

    public ValueOptionBuilder() {

    }

    public ValueOptionBuilder setDefaultValue(String defaultValue) {
        if (defaultValue == null) {
            this.defaultValue = "";
        } else {
            this.defaultValue = defaultValue;
        }
        return this;
    }

    public ValueOption toValueOption() {
        return new InternalValueOption(defaultValue);
    }

    public static ValueOptionBuilder init() {
        return new ValueOptionBuilder();
    }

    public static ValueOptionBuilder derive(ValueOption valueOption) {
        return ValueOptionBuilder.init()
                .setDefaultValue(valueOption.getDefaultValue());
    }


    private static class InternalValueOption implements ValueOption {

        private final String defaultValue;

        public InternalValueOption(String defaultValue) {
            this.defaultValue = defaultValue;
        }

        @Override
        public String getDefaultValue() {
            return defaultValue;
        }

    }

}
