/* FichothequeLib_Tools - Copyright (c) 2010-2023 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package net.fichotheque.tools.extraction.builders;

import java.util.List;
import net.fichotheque.corpus.metadata.FieldKey;
import net.fichotheque.extraction.def.FicheFilter;
import net.fichotheque.extraction.def.TagNameInfo;
import net.fichotheque.extraction.filterunit.CorpsdeficheFilterUnit;
import net.fichotheque.extraction.filterunit.FieldKeyFilterUnit;
import net.fichotheque.extraction.filterunit.FieldNamePrefixFilterUnit;
import net.fichotheque.extraction.filterunit.FilterUnit;


/**
 *
 * @author Vincent Calame
 */
public class FicheFilterBuilder {

    private final FilterUnitListBuilder filterUnitListBuilder;
    private TagNameInfo tagNameInfo = TagNameInfo.DEFAULT;

    public FicheFilterBuilder() {
        this.filterUnitListBuilder = new FilterUnitListBuilder();
    }

    public FilterUnitListBuilder getFilterUnitListBuilder() {
        return filterUnitListBuilder;
    }

    public FicheFilterBuilder setTagNameInfo(TagNameInfo tagNameInfo) {
        this.tagNameInfo = tagNameInfo;
        return this;
    }

    private boolean testCorpsdefiche(short category) {
        switch (category) {
            case FieldKey.SECTION_CATEGORY:
                return true;
            default:
                return false;
        }
    }

    public FicheFilter toFicheFilter() {
        List<FilterUnit> filterUnitList = filterUnitListBuilder.toFilterUnitList();
        boolean withCorpsdefiche = false;
        for (FilterUnit filterUnit : filterUnitList) {
            if (filterUnit instanceof CorpsdeficheFilterUnit) {
                withCorpsdefiche = true;
                break;
            } else if (filterUnit instanceof FieldKeyFilterUnit) {
                boolean test = testCorpsdefiche(((FieldKeyFilterUnit) filterUnit).getFieldKey().getCategory());
                if (test) {
                    withCorpsdefiche = true;
                    break;
                }
            } else if (filterUnit instanceof FieldNamePrefixFilterUnit) {
                boolean test = testCorpsdefiche(((FieldNamePrefixFilterUnit) filterUnit).getCategory());
                if (test) {
                    withCorpsdefiche = true;
                    break;
                }
            }
        }
        return new InternalFicheFilter(tagNameInfo, filterUnitList, withCorpsdefiche);
    }

    public static FicheFilterBuilder init() {
        return new FicheFilterBuilder();
    }


    private static class InternalFicheFilter implements FicheFilter {

        private final TagNameInfo tagNameInfo;
        private final List<FilterUnit> filterUnitList;
        private final boolean withCorpsdefiche;


        private InternalFicheFilter(TagNameInfo tagNameInfo, List<FilterUnit> filterUnitList, boolean withCorpsdefiche) {
            this.tagNameInfo = tagNameInfo;
            this.filterUnitList = filterUnitList;
            this.withCorpsdefiche = withCorpsdefiche;
        }

        @Override
        public TagNameInfo getTagNameInfo() {
            return tagNameInfo;
        }

        @Override
        public boolean isWithCorpsdefiche() {
            return withCorpsdefiche;
        }

        @Override
        public List<FilterUnit> getFilterUnitList() {
            return filterUnitList;
        }

    }


}
